==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/GetGraphQLApiResolverPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.GetGraphQLApiResolverPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property apiId API revision identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
 * @property resolverId Resolver identifier within a GraphQL API. Must be unique in the current API Management service instance.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property serviceName The name of the API Management service.
 */
public data class GetGraphQLApiResolverPlainArgs(
    public val apiId: String,
    public val resolverId: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.GetGraphQLApiResolverPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.apimanagement.inputs.GetGraphQLApiResolverPlainArgs =
        com.pulumi.azurenative.apimanagement.inputs.GetGraphQLApiResolverPlainArgs.builder()
            .apiId(apiId.let({ args0 -> args0 }))
            .resolverId(resolverId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetGraphQLApiResolverPlainArgs].
 */
@PulumiTagMarker
public class GetGraphQLApiResolverPlainArgsBuilder internal constructor() {
    private var apiId: String? = null

    private var resolverId: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value API revision identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
     */
    @JvmName("nmjgbihecrvgmoms")
    public suspend fun apiId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.apiId = mapped
    }

    /**
     * @param value Resolver identifier within a GraphQL API. Must be unique in the current API Management service instance.
     */
    @JvmName("prmywsnqakwcwxjy")
    public suspend fun resolverId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resolverId = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("ruuaxpuxgfqdbdfh")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the API Management service.
     */
    @JvmName("auawjaqdeqqqdrad")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): GetGraphQLApiResolverPlainArgs = GetGraphQLApiResolverPlainArgs(
        apiId = apiId ?: throw PulumiNullFieldException("apiId"),
        resolverId = resolverId ?: throw PulumiNullFieldException("resolverId"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/GetGraphQLApiResolverPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.GetGraphQLApiResolverPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property apiId API revision identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
 * @property resolverId Resolver identifier within a GraphQL API. Must be unique in the current API Management service instance.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property serviceName The name of the API Management service.
 */
public data class GetGraphQLApiResolverPlainArgs(
    public val apiId: String,
    public val resolverId: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.GetGraphQLApiResolverPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.apimanagement.inputs.GetGraphQLApiResolverPlainArgs =
        com.pulumi.azurenative.apimanagement.inputs.GetGraphQLApiResolverPlainArgs.builder()
            .apiId(apiId.let({ args0 -> args0 }))
            .resolverId(resolverId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetGraphQLApiResolverPlainArgs].
 */
@PulumiTagMarker
public class GetGraphQLApiResolverPlainArgsBuilder internal constructor() {
    private var apiId: String? = null

    private var resolverId: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value API revision identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
     */
    @JvmName("stxdtkolgynixlyy")
    public suspend fun apiId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.apiId = mapped
    }

    /**
     * @param value Resolver identifier within a GraphQL API. Must be unique in the current API Management service instance.
     */
    @JvmName("cqrowlgiwlxnjjqt")
    public suspend fun resolverId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resolverId = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("yoyfvxpihnwaabpv")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the API Management service.
     */
    @JvmName("wvdkldbshajffxei")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): GetGraphQLApiResolverPlainArgs = GetGraphQLApiResolverPlainArgs(
        apiId = apiId ?: throw PulumiNullFieldException("apiId"),
        resolverId = resolverId ?: throw PulumiNullFieldException("resolverId"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
    )
}
